import setuptools

setuptools.setup(
    name="exeNake",
    version="0.0.1",
    author="Comet",
    author_email="9su0425@gmail.com",
    description="strong Multiple-Run-Token System",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.12",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.11',
)
